quantizationtools.QGridContainer
================================

.. abjad-lineage:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer

.. autoclass:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.children
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.contents_duration
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.depth
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.depthwise_inventory
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.graph_order
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.graphviz_format
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.graphviz_graph
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.improper_parentage
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.leaves
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.nodes
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.parent
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.parentage_ratios
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.pretty_rtm_format
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.prolation
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.prolations
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.proper_parentage
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.root
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.rtm_format
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.start_offset
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.storage_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.duration
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.append
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.extend
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.index
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.insert
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.pop
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.remove
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__add__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__call__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__contains__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__delitem__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__ge__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__getitem__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__getstate__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__gt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__iter__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__le__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__len__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__lt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__repr__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__setitem__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridContainer.QGridContainer.QGridContainer.__setstate__
   :noindex:
